@@ -65,6 +65,13 @@ enum {
 
 static GParamSpec *obj_props[PROP_LAST];
 
+enum {
+        CONFIRM,
+        LAST_SIGNAL
+};
+
+static guint signals[LAST_SIGNAL] = { 0 };
+
 typedef struct {
         GtkWidget *box;
         GtkWidget *checkmark;
@@ -208,6 +215,7 @@ more_widget_new (void)
         gtk_widget_set_margin_bottom (widget, 10);
         gtk_misc_set_alignment (GTK_MISC (arrow), 0.5, 0.5);
         gtk_box_pack_start (GTK_BOX (widget), arrow, TRUE, TRUE, 0);
+        gtk_widget_show_all (widget);
 
         return widget;
 }
@@ -470,6 +478,16 @@ set_locale_id (CcRegionChooser *chooser,
         g_object_notify_by_pspec (G_OBJECT (chooser), obj_props[PROP_LOCALE]);
 }
 
+static gboolean
+confirm_choice (gpointer data)
+{
+        GtkWidget *widget = data;
+
+        g_signal_emit (widget, signals[CONFIRM], 0);
+
+        return G_SOURCE_REMOVE;
+}
+
 static void
 row_activated (GtkListBox        *box,
                GtkListBoxRow     *row,
@@ -489,7 +507,10 @@ row_activated (GtkListBox        *box,
                 widget = get_region_widget (child);
                 if (widget == NULL)
                         return;
-                set_locale_id (chooser, widget->locale_id);
+                if (g_strcmp0 (priv->locale, widget->locale_id) == 0)
+                        g_idle_add (confirm_choice, chooser);
+                else
+                        set_locale_id (chooser, widget->locale_id);
         }
 }
 
@@ -517,7 +538,6 @@ cc_region_chooser_constructed (GObject *object)
         G_OBJECT_CLASS (cc_region_chooser_parent_class)->constructed (object);
 
         priv->more_item = more_widget_new ();
-        gtk_container_add (GTK_CONTAINER (priv->region_list), priv->more_item);
 
         priv->no_results = no_results_widget_new ();
 
@@ -541,6 +561,8 @@ cc_region_chooser_constructed (GObject *object)
 
 	add_all_regions (chooser);
 
+	gtk_container_add (GTK_CONTAINER (priv->region_list), priv->more_item);
+
         g_signal_connect (priv->filter_entry, "changed",
                           G_CALLBACK (filter_changed),
                           chooser);
@@ -599,10 +621,22 @@ cc_region_chooser_set_property (GObject      *object,
         }
 }
 
+static void
+cc_region_chooser_map (GtkWidget *widget)
+{
+        CcRegionChooser *chooser = CC_REGION_CHOOSER (widget);
+        CcRegionChooserPrivate *priv = cc_region_chooser_get_instance_private (chooser);
+
+        gtk_list_box_invalidate_filter (GTK_LIST_BOX (priv->region_list));
+
+        GTK_WIDGET_CLASS (cc_region_chooser_parent_class)->map (widget);
+}
+
 static void
 cc_region_chooser_class_init (CcRegionChooserClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
+        GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
         gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/control-center/region-chooser.ui");
 
@@ -615,6 +649,16 @@ cc_region_chooser_class_init (CcRegionChooserClass *klass)
         object_class->set_property = cc_region_chooser_set_property;
         object_class->constructed = cc_region_chooser_constructed;
 
+        signals[CONFIRM] = g_signal_new ("confirm",
+                                         G_TYPE_FROM_CLASS (object_class),
+                                         G_SIGNAL_RUN_FIRST,
+                                         G_STRUCT_OFFSET (CcRegionChooserClass, confirm),
+                                         NULL, NULL,
+                                         g_cclosure_marshal_VOID__VOID,
+                                         G_TYPE_NONE, 0);
+
+        widget_class->map = cc_region_chooser_map;
+
         obj_props[PROP_LOCALE] =
                 g_param_spec_string ("locale", "", "", "",
                                      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
